summaryrefslogtreecommitdiffstats
path: root/monitor/trust_group.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'monitor/trust_group.hpp')
-rw-r--r--monitor/trust_group.hpp7
1 files changed, 5 insertions, 2 deletions
diff --git a/monitor/trust_group.hpp b/monitor/trust_group.hpp
index af7b372..e0db5c9 100644
--- a/monitor/trust_group.hpp
+++ b/monitor/trust_group.hpp
@@ -112,7 +112,8 @@ class Group
}
/**
* Starts the timers on all functional sensors in the group.
*
* Called when the group just changed to trusted.
*/
@@ -125,7 +126,9 @@ class Group
{
//If a sensor isn't functional, then its timer
//already expired so don't bother starting it again
- if (s.get()->functional())
+ if (s.get()->functional() &&
+ static_cast<uint64_t>(s.get()->getInput()) !=
+ s.get()->getTarget())
{
s.get()->startTimer();
}
@@ -112,7 +112,8 @@ class Group
}
/**
- * Starts the timers on all functional sensors in the group.
+ * Starts the timers on all functional sensors in the group if
+ * their target and input values do not match.
*
* Called when the group just changed to trusted.
OpenPOWER on IntegriCloud